@@ -1,7 +1,9 @@
 package POEx::IRC::Backend;
-$POEx::IRC::Backend::VERSION = '0.027002';
-use strictures 1;
+$POEx::IRC::Backend::VERSION = '0.027003';
+use strictures 2;
+
 use Carp;
+use Scalar::Util 'blessed';
 
 use IRC::Message::Object 'ircmsg';
 
@@ -35,7 +37,7 @@ use POEx::IRC::Backend::_Util;
 sub RUNNING_IN_HELL () { $^O =~ /(cygwin|MSWin32)/ }
 
 
-use Moo; use MooX::late;
+use Moo;
 
 
 has session_id => (
@@ -627,12 +629,13 @@ sub send {
   my ($self, $out, @ids) = @_;
 
   if (blessed $out && $out->isa('IRC::Message::Object')) {
+    # breaks encapsulation for performance reasons:
     $out = +{
       command => $out->command,
-      ( $out->has_prefix ? (prefix  => $out->prefix) : () ),
-      ( $out->has_params ? (params  => $out->params) : () ),
-      ( $out->has_tags   ? (tags    => $out->tags  ) : () ),
-      ( $out->has_colonify ? (colonify => $out->colonify) : () ),
+      (
+        map {; exists $out->{$_} ? ($_ => $out->{$_}) : () }
+          qw/ colonify prefix params tags /
+      ),
     };
   }
 
