@@ -1,9 +1,8 @@
 package POEx::IRC::Backend::Connect;
-$POEx::IRC::Backend::Connect::VERSION = '0.027002';
-use Carp;
+$POEx::IRC::Backend::Connect::VERSION = '0.027003';
 use Types::Standard -all;
 
-use Moo; use MooX::late;
+use Moo;
 with 'POEx::IRC::Backend::Role::HasWheel';
 
 has args => (
