@@ -1,8 +1,8 @@
 package POEx::IRC::Backend::Listener;
-$POEx::IRC::Backend::Listener::VERSION = '0.027002';
+$POEx::IRC::Backend::Listener::VERSION = '0.027003';
 use Types::Standard -types;
 
-use Moo; use MooX::late;
+use Moo;
 with 'POEx::IRC::Backend::Role::Connector';
 
 has idle  => (
