@@ -1,6 +1,6 @@
 package POEx::IRC::Backend::Role::Connector;
-$POEx::IRC::Backend::Role::Connector::VERSION = '0.027002';
-use Moo::Role; use MooX::late;
+$POEx::IRC::Backend::Role::Connector::VERSION = '0.027003';
+use Moo::Role;
 with 'POEx::IRC::Backend::Role::HasWheel';
 
 has addr => (
