@@ -1,9 +1,8 @@
 package POEx::IRC::Backend::Role::HasWheel;
-$POEx::IRC::Backend::Role::HasWheel::VERSION = '0.027002';
-use strictures 1;
-
+$POEx::IRC::Backend::Role::HasWheel::VERSION = '0.027003';
 use Types::Standard -all;
-use Moo::Role; use MooX::late;
+
+use Moo::Role;
 
 has wheel_id => (
   lazy    => 1,
